@@ -19,15 +19,21 @@ class Info(BaseModel):
     **REQUIRED**. The title of the API.
     """
 
+    summary: Optional[str] = None
+    """
+    A short summary of the API.
+    """
+
     description: Optional[str] = None
     """
-    A short description of the API.
+    A description of the API.
     [CommonMark syntax](https://spec.commonmark.org/) MAY be used for rich text representation.
     """
 
     termsOfService: Optional[AnyUrl] = None
     """
-    A URL to the Terms of Service for the API. MUST be in the format of a URL.
+    A URL to the Terms of Service for the API.
+    MUST be in the form of a URL.
     """
 
     contact: Optional[Contact] = None
@@ -43,7 +49,7 @@ class Info(BaseModel):
     version: str
     """
     **REQUIRED**. The version of the OpenAPI document
-    (which is distinct from the [OpenAPI Specification version](https://spec.openapis.org/oas/v3.0.3#oasVersion) or the API implementation version).
+    (which is distinct from the [OpenAPI Specification version](https://spec.openapis.org/oas/v3.1.0#oasVersion)) or the API implementation version).
     """
 
     class Config:
@@ -52,6 +58,7 @@ class Info(BaseModel):
             "examples": [
                 {
                     "title": "Sample Pet Store App",
+                    "summary": "A pet store manager.",
                     "description": "This is a sample server for a pet store.",
                     "termsOfService": "http://example.com/terms/",
                     "contact": {
